:tocdepth: 2

.. _authors:

Authors
=======

py7zr is written and maintained by Hiroshi Miura <miurahr@linux.com>

Contributors, listed alphabetically, are:

* Alan Lee -- Update documentation
* Alexander Kapshuna -- Fix shutil integration (#353)
* @andrebrait -- Fix exception for empty 7z file (#118)
* @amarcu5 -- fix error when large compressed headers (#281)
* c.foster -- Default exceptions to include the exception type
* chigusa -- Fix UTF-16 path parsing for extraction (#391)
* @DoNCK -- Fix extraction of hidden dot files(#448)
* Jasper Lievisse Adriaanse -- Update document
* Joachim Bauch -- pylzma orginator
* Kazuya Fujioka -- Fix zero file problem
* Kyle Altendorf -- Fix multithreading problem (#82)
* Martin Larralde -- Fix writef method (#397)
* Megan Leet -- Fix infinite loop when extraction (#354)
* @padremayi -- Fix crash on wrong crationtime in archive (#275)
* @royopa -- Fix typo (#108)
* T. Yamada -- Deflate64 decompression (#399)
* @Zoynels -- Mmeory IO API(#111, #119)
